@@ -20,7 +20,7 @@ package Lucy;
 
 use 5.008003;
 
-our $VERSION = '0.006000004';
+our $VERSION = '0.006001';
 $VERSION = eval $VERSION;
 our $MAJOR_VERSION = 0.006000;
 
@@ -49,12 +49,12 @@ BEGIN {
     require DynaLoader;
     our @ISA = qw( DynaLoader );
     # This loads a large number of disparate subs.
-    bootstrap Lucy '0.6.0.4';
+    bootstrap Lucy '0.6.1';
 }
 
 {
     package Lucy::Util::IndexFileNames;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     BEGIN {
         push our @ISA, 'Exporter';
@@ -73,7 +73,7 @@ BEGIN {
 
 {
     package Lucy::Analysis::RegexTokenizer;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
 
     sub _compile_token_re {qr/$_[0]/}
@@ -88,7 +88,7 @@ BEGIN {
 
 {
     package Lucy::Document::Doc;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Storable ();  # Needed by serialize/deserialize.
     use Lucy qw( STORABLE_freeze STORABLE_thaw );
@@ -100,14 +100,14 @@ BEGIN {
 
 {
     package Lucy::Index::DocVector;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Lucy qw( STORABLE_freeze STORABLE_thaw );
 }
 
 {
     package Lucy::Index::Indexer;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
 
     sub new {
@@ -121,7 +121,7 @@ BEGIN {
 
 {
     package Lucy::Index::IndexReader;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Carp;
 
@@ -146,21 +146,21 @@ BEGIN {
 
 {
     package Lucy::Index::Similarity;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Lucy qw( STORABLE_freeze STORABLE_thaw );
 }
 
 {
     package Lucy::Index::TermVector;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Lucy qw( STORABLE_freeze STORABLE_thaw );
 }
 
 {
     package Lucy::Search::Compiler;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Carp;
     use Scalar::Util qw( blessed );
@@ -179,21 +179,21 @@ BEGIN {
 
 {
     package Lucy::Search::MatchDoc;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Lucy qw( STORABLE_freeze STORABLE_thaw );
 }
 
 {
     package Lucy::Search::Query;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Lucy qw( STORABLE_freeze STORABLE_thaw );
 }
 
 {
     package Lucy::Search::SortRule;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Carp;
     use Lucy qw( STORABLE_freeze STORABLE_thaw );
@@ -214,28 +214,28 @@ BEGIN {
 
 {
     package Lucy::Search::SortSpec;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Lucy qw( STORABLE_freeze STORABLE_thaw );
 }
 
 {
     package Lucy::Search::TopDocs;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     use Lucy qw( STORABLE_freeze STORABLE_thaw );
 }
 
 {
     package Lucy::Object::BitVector;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     sub to_arrayref { shift->to_array->to_arrayref }
 }
 
 {
     package Lucy::Store::FileHandle;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     BEGIN {
         push our @ISA, 'Exporter';
@@ -262,7 +262,7 @@ BEGIN {
 
 {
     package Lucy::Store::FSFileHandle;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
 
     sub open {
@@ -275,7 +275,7 @@ BEGIN {
 
 {
     package Lucy::Store::RAMFileHandle;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
 
     sub open {
@@ -288,7 +288,7 @@ BEGIN {
 
 {
     package Lucy::Util::Debug;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     BEGIN {
         push our @ISA, 'Exporter';
@@ -307,7 +307,7 @@ BEGIN {
 
 {
     package Lucy::Util::StringHelper;
-    our $VERSION = '0.006000004';
+    our $VERSION = '0.006001';
     $VERSION = eval $VERSION;
     BEGIN {
         push our @ISA, 'Exporter';
