@@ -18,7 +18,7 @@ use warnings;
 
 package LucyX::Remote::SearchClient;
 BEGIN { our @ISA = qw( Lucy::Search::Searcher ) }
-our $VERSION = '0.006000004';
+our $VERSION = '0.006001';
 $VERSION = eval $VERSION;
 use Carp;
 use Storable qw( nfreeze thaw );
@@ -51,7 +51,12 @@ sub new {
 
 sub DESTROY {
     my $self = shift;
-    $self->close if defined $sock{$$self};
+    if ( defined $sock{$$self} ) {
+        # Ignore exceptions in destructor.
+        eval {
+            $self->close;
+        };
+    }
     delete $peer_address{$$self};
     delete $sock{$$self};
     $self->SUPER::DESTROY;
